@@ -1,23 +1,10 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author: Kevin Ottens <kevin@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Kevin Ottens <kevin@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "session.h"
@@ -161,7 +148,7 @@ SessionPrivate::~SessionPrivate()
 void SessionPrivate::addJob(Job *job)
 {
     queue.append(job);
-    emit q->jobQueueSizeChanged(q->jobQueueSize());
+    Q_EMIT q->jobQueueSizeChanged(q->jobQueueSize());
 
     QObject::connect(job, &KJob::result, this, &SessionPrivate::jobDone);
     QObject::connect(job, &QObject::destroyed, this, &SessionPrivate::jobDestroyed);
@@ -198,7 +185,7 @@ void SessionPrivate::jobDone(KJob *job)
 
     jobRunning = false;
     currentJob = nullptr;
-    emit q->jobQueueSizeChanged(q->jobQueueSize());
+    Q_EMIT q->jobQueueSizeChanged(q->jobQueueSize());
     startNext();
 }
 
@@ -313,7 +300,7 @@ void SessionPrivate::setState(Session::State s)
     if (s != state) {
         Session::State oldState = state;
         state = s;
-        emit q->stateChanged(state, oldState);
+        Q_EMIT q->stateChanged(state, oldState);
     }
 }
 
@@ -392,9 +379,9 @@ void SessionPrivate::socketDisconnected()
 
     if (isSocketConnected) {
         setState(Session::Disconnected);
-        emit q->connectionLost();
+        Q_EMIT q->connectionLost();
     } else {
-        emit q->connectionFailed();
+        Q_EMIT q->connectionFailed();
     }
 
     isSocketConnected = false;
@@ -423,7 +410,7 @@ void SessionPrivate::socketError(QAbstractSocket::SocketError error)
     if (isSocketConnected) {
         thread->closeSocket();
     } else {
-        emit q->connectionFailed();
+        Q_EMIT q->connectionFailed();
         clearJobQueue();
     }
 }
@@ -440,7 +427,7 @@ void SessionPrivate::clearJobQueue()
     QQueue<Job *> queueCopy = queue; // copy because jobDestroyed calls removeAll
     qDeleteAll(queueCopy);
     queue.clear();
-    emit q->jobQueueSizeChanged(0);
+    Q_EMIT q->jobQueueSizeChanged(0);
 }
 
 void SessionPrivate::startSsl(QSsl::SslProtocol protocol)
@@ -460,7 +447,7 @@ void SessionPrivate::onEncryptionNegotiationResult(bool isEncrypted, QSsl::SslPr
     } else {
         sslVersion = QSsl::UnknownProtocol;
     }
-    emit encryptionNegotiationResult(isEncrypted);
+    Q_EMIT encryptionNegotiationResult(isEncrypted);
 }
 
 QSsl::SslProtocol SessionPrivate::negotiatedEncryption() const
